@@ -1,33 +1,33 @@
 #' Competings Risks Regression
 #' 
 #' Fits a semiparametric model for the cause-specific quantities : \deqn{ P(T <
-#' t, cause=1 | x,z) = P_1(t,x,z) = h( g(t,x,z) ) } for a known link-function
+#' t, cause=1 | x,z) = P_1(t,x,z) = h( g(t,x,z) ) }{} for a known link-function
 #' \eqn{h()} and known prediction-function \eqn{g(t,x,z)} for the probability
 #' of dying from cause 1 in a situation with competing causes of death.
 #' 
 #' We consider the following models : 1) the additive model where
 #' \eqn{h(x)=1-\exp(-x)} and \deqn{ g(t,x,z) = x^T A(t) + (diag(t^p) z)^T \beta
-#' } 2) the proportional setting that includes the Fine & Gray (FG) "prop"
+#' }{} 2) the proportional setting that includes the Fine & Gray (FG) "prop"
 #' model and some extensions where \eqn{h(x)=1-\exp(-\exp(x))} and \deqn{
-#' g(t,x,z) = (x^T A(t) + (diag(t^p) z)^T \beta) } The FG model is obtained
+#' g(t,x,z) = (x^T A(t) + (diag(t^p) z)^T \beta) }{} The FG model is obtained
 #' when \eqn{x=1}, but the baseline is parametrized as \eqn{\exp(A(t))}.
 #' 
 #' The "fg" model is a different parametrization that contains the FG model,
 #' where \eqn{h(x)=1-\exp(-x)} and \deqn{ g(t,x,z) = (x^T A(t)) \exp((diag(t^p)
-#' z)^T \beta) } The FG model is obtained when \eqn{x=1}.
+#' z)^T \beta) }{} The FG model is obtained when \eqn{x=1}.
 #' 
 #' 3) a "logistic" model where \eqn{h(x)=\exp(x)/( 1+\exp(x))} and \deqn{
-#' g(t,x,z) = x^T A(t) + (diag(t^p) z)^T \beta }
+#' g(t,x,z) = x^T A(t) + (diag(t^p) z)^T \beta}{} 
 #' 
 #' The "logistic2" is \deqn{ P_1(t,x,z) = x^T A(t) exp((diag(t^p) z)^T \beta)/
-#' (1+ x^T A(t) exp((diag(t^p) z)^T \beta)) } The simple logistic model with
+#' (1+ x^T A(t) exp((diag(t^p) z)^T \beta)) }{} The simple logistic model with
 #' just a baseline can also be fitted by an alternative procedure that has
 #' better small sample properties see prop.odds.subist().
 #' 
 #' 4) the relative cumulative incidence function "rcif" model where
-#' \eqn{h(x)=\exp(x)} and \deqn{ g(t,x,z) = x^T A(t) + (diag(t^p) z)^T \beta }
+#' \eqn{h(x)=\exp(x)} and \deqn{ g(t,x,z) = x^T A(t) + (diag(t^p) z)^T \beta }{}
 #' 
-#' The "rcif2" \deqn{ P_1(t,x,z) = (x^T A(t)) \exp((diag(t^p) z)^T \beta) }
+#' The "rcif2" \deqn{ P_1(t,x,z) = (x^T A(t)) \exp((diag(t^p) z)^T \beta) }{}
 #' 
 #' Where p by default is 1 for the additive model and 0 for the other models.
 #' In general p may be powers of the same length as z.
@@ -105,9 +105,7 @@
 #' @param admin.cens censoring times for the administrative censoring
 #' @param conservative set to 0 to compute correct variances based on censoring
 #' weights, default is conservative estimates that are much quicker.
-#' @param monotone monotone=0, uses estimating equations \deqn{ (D_\beta P_1)
-#' w(t) ( Y(t)/G_c(t) - P_1(t,X)) and } montone 1 uses \deqn{ w(t) (
-#' Y(t)/G_c(t) - P_1(t,X)) and }
+#' @param monotone monotone=0, uses estimating equations \deqn{ (D_\beta P_1) w(t) ( Y(t)/G_c(t) - P_1(t,X))}{} montone=1 uses \deqn{ w(t) X ( Y(t)/G_c(t) - P_1(t,X)) }{}
 #' @param step step size for Fisher-Scoring algorithm.
 #' @return returns an object of type 'comprisk'. With the following arguments:
 #' \item{cum}{cumulative timevarying regression coefficient estimates are
@@ -169,14 +167,6 @@
 #' par(mfrow=c(2,2))
 #' plot(out,multiple=0,uniform=1,col=1:3,lty=1,se=1)
 #' 
-#' add<-comp.risk(Event(time,cause)~platelet+age+tcell,data=bmt,
-#' 	       cause=1,resample.iid=0,n.sim=0,cens.model="cox",
-#' 	       cens.formula=~factor(platelet),model="additive")
-#' 
-#' out<-predict(add,ndata,se=0,uniform=0)
-#' par(mfrow=c(2,2))
-#' plot(out,multiple=0,se=0,uniform=0,col=1:3,lty=1)
-#' 
 #' ## fits additive model with some constant effects 
 #' add.sem<-comp.risk(Event(time,cause)~
 #' const(platelet)+const(age)+const(tcell),data=bmt,
@@ -301,7 +291,7 @@ comp.risk<-function(formula,data=parent.frame(),cause,times=NULL,Nit=50,clusters
     intercept <- attr(mt, "intercept")
     event.history <- model.extract(m, "response")
 
-  if (class(event.history)!="Event"){
+  if (!inherits(event.history,"Event")){
        stop("Since timereg version 1.8.6.: The left hand side of the formula must be specified as 
        Event(time, event) or with non default censoring codes Event(time, event, cens.code=0).")
   }
@@ -402,26 +392,29 @@ comp.risk<-function(formula,data=parent.frame(),cause,times=NULL,Nit=50,clusters
 		if (!is.null(trunc.p)) Gcx <- Gcx/Gcxe; 
                 Gctimes<-Cpred(Gfit,times)[,2]; ## }}}
             } else if (cens.model=="cox") { ## {{{
-                if (!is.null(cens.formula)) { 
-		      XZ <- model.matrix(cens.formula,data=data); 
-                      if (sum(XZ[,1])==nrow(XZ)) XZ <- as.matrix(XZ[,-1])
-                } else {
-                       if (npar==TRUE) XZ<-X[,-1] else XZ <-cbind(X,Z)[,-1];
-                }
-		if (left==1) ud.cens<-coxph(Surv(entrytime,eventtime,delta==cens.code)~XZ)                
-		else ud.cens<-coxph(Surv(eventtime,delta==cens.code)~XZ)                
-		baseout <- basehaz(ud.cens,centered=FALSE); 
-		baseout <- cbind(baseout$time,baseout$hazard)
-		Gcx<-Cpred(baseout,eventtime,strict=TRUE)[,2];
-		Gcxe<-Cpred(baseout,entrytime,strict=TRUE)[,2];
-		Gcxe[Gcxe==0] <- 1
-		RR<-exp(as.matrix(XZ) %*% coef(ud.cens))
-		Gcx<-exp(-Gcx*RR)
-		Gcxe<-exp(-Gcxe*RR)
-		Gfit<-rbind(c(0,1),cbind(eventtime,Gcx)); 
-		### only conditional on L if trunc given 
-		if (!is.null(trunc.p)) Gcx <- Gcx/Gcxe; 
-		Gctimes<-Cpred(Gfit,times,strict=TRUE)[,2]; 
+                     stop("Disabbled \n"); 
+###                if (!is.null(cens.formula)) { 
+###			data$eventtime__ <- eventtime
+###			data$entrytime__ <- entrytime 
+###			data$delta__C <- delta==cens.code
+###		if (left==1) 
+###                formC <- update.formula(cens.formula,Surv(entrytime__,eventtime__,delta__C)~.)
+###	         else formC <- update.formula(cens.formula,Surv(eventtime__,delta__C)~.)
+###                } else {
+###                }
+###		ud.cens<-coxph(formC,data=data)                
+###		baseout <- basehaz(ud.cens,centered=FALSE); 
+###		baseout <- cbind(baseout$time,baseout$hazard)
+###		Gcx<-Cpred(baseout,eventtime,strict=TRUE)[,2];
+###		Gcxe<-Cpred(baseout,entrytime,strict=TRUE)[,2];
+###		Gcxe[Gcxe==0] <- 1
+###		RR<-exp(as.matrix(XZ) %*% coef(ud.cens))
+###		Gcx<-exp(-Gcx*RR)
+###		Gcxe<-exp(-Gcxe*RR)
+###		Gfit<-rbind(c(0,1),cbind(eventtime,Gcx)); 
+###		### only conditional on L if trunc given 
+###		if (!is.null(trunc.p)) Gcx <- Gcx/Gcxe; 
+###		Gctimes<-Cpred(Gfit,times,strict=TRUE)[,2]; 
                 ## }}}
             } else if (cens.model=="aalen") {  ## {{{
                 if (!is.null(cens.formula)) { 
@@ -1026,8 +1019,14 @@ prep.comp.risk <- function(data,times=NULL,entrytime=NULL,
 	   } else Lw <- 1
 ###
 	cens.model <- coxph(Surv(entrytime,data[,time],data[,cause]==0)~+X) 
-        baseout <- basehaz(cens.model,centered=FALSE); 
-	baseout <- cbind(baseout$time,baseout$hazard)
+###        baseout <- basehaz(cens.model,centered=FALSE); 
+###	baseout <- cbind(baseout$time,baseout$hazard)
+        sfit <- survfit(cens.model, se.fit=FALSE)   
+        zcoef <- ifelse(is.na(coef(cens.model)), 0, coef(cens.model))
+        offset <- sum(cens.model$means * zcoef)
+        chaz <- sfit$cumhaz * exp(-offset)
+        baseout <- cbind(sfit$time,chaz)  
+
 	Gfit<-Cpred(baseout,pmin(mtt,data[,time]),strict=TRUE)[,2];
 	RR<-exp(as.matrix(X) %*% coef(cens.model))
 	Gfit<-exp(-Gfit*RR)
