@@ -6,14 +6,14 @@
 #' 
 #' The model specifikatin allows a regression structure on the variance of the
 #' random effects, such it is allowed to depend on covariates fixed within
-#' clusters \deqn{ \theta_{k} = Q_{k}^T \nu }. This is particularly useful to
+#' clusters \deqn{ \theta_{k} = Q_{k}^T \nu }{}. This is particularly useful to
 #' model jointly different groups and to compare their variances.
 #' 
 #' Fits an Cox-Aalen survival model.  Time dependent variables and counting
 #' process data (multiple events per subject) are not possible !
 #' 
 #' The marginal baselines are on the Cox-Aalen form \deqn{ \lambda_{ki}(t) =
-#' Y_{ki}(t) ( X_{ki}^T(t) \alpha(t) ) \exp(Z_{ki}^T \beta ) }
+#' Y_{ki}(t) ( X_{ki}^T(t) \alpha(t) ) \exp(Z_{ki}^T \beta ) }{}
 #' 
 #' The model thus contains the Cox's regression model and the additive hazards
 #' model as special cases. (see cox.aalen function for more on this).
@@ -139,7 +139,7 @@ robust=1,theta=NULL,theta.des=NULL,var.link=0,step=0.5,notaylor=0,se.clusters=NU
 ## {{{ seting up design and variables
 rate.sim <- 1; secluster <- NULL
 
-if (class(margsurv)!="coxph") { ## {{{ 
+if (!inherits(margsurv,"coxph")) { ## {{{ 
  formula<-attr(margsurv,"Formula");
  beta.fixed <- attr(margsurv,"beta.fixed")
  if (is.null(beta.fixed)) beta.fixed <- 1; 
@@ -208,7 +208,7 @@ if (class(margsurv)!="coxph") { ## {{{
 ###  if (anyNA(idiclust)) idiclust[is.na(idiclust)] <- 0
 
   ### setting secluster after cluster.index call to deal with characters 
-  if (class(margsurv)=="coxph") {
+  if (inherits(margsurv,"coxph")) {
   if (is.null(se.clusters) & is.null(secluster) ) secluster <- clusters;
   antsecluster <- length(unique(secluster))
   if (is.numeric(secluster)) secluster <-  sindex.prodlim(unique(secluster),secluster)-1 else  {
@@ -239,7 +239,7 @@ if (class(margsurv)!="coxph") { ## {{{
   } ## }}}
 
   if (update==1) 
-  if (class(margsurv)=="aalen" || class(margsurv)=="cox.aalen")  { ## {{{
+  if (inherits(margsurv,c("aalen","cox.aalen")))  { ## {{{
      if ((attr(margsurv,"residuals")!=2) || (lefttrunk==1)) { 
          resi <- residualsTimereg(margsurv,data=data) 
          residuals <- resi$residuals; 
@@ -248,18 +248,22 @@ if (class(margsurv)!="coxph") { ## {{{
 	 RR <- resi$RR
      } else { residuals <- margsurv$residuals$dM; 
               cumhaz <- status-residuals; 
-	      if (class(margsurv)=="cox.aalen") RR  <- exp( Z %*% margsurv$gamma)
+	      if (inherits(margsurv,"cox.aalen")) RR  <- exp( Z %*% margsurv$gamma)
      }
   }
-  else if (class(margsurv)=="coxph") {
+  else if (inherits(margsurv,"coxph")) {
        notaylor <- 1
        residuals <- residuals(margsurv)
        cumhaz <- status-residuals
        cumhazleft <- rep(0,antpers)
        RR<- exp(margsurv$linear.predictors-sum(margsurv$means*coef(margsurv)))
         if ((lefttrunk==1)) { 
-           baseout <- basehaz(margsurv,centered=FALSE); 
-           cum <- cbind(baseout$time,baseout$hazard)
+###           baseout <- basehaz(margsurv,centered=FALSE); 
+             sfit <- survfit(margsurv, se.fit=FALSE)   
+             zcoef <- ifelse(is.na(coef(margsurv)), 0, coef(margsurv))
+             offset <- sum(margsurv$means * zcoef)
+             chaz <- sfit$cumhaz * exp(-offset)
+             cum <- cbind(sfit$time,chaz)  
 	   cum <- Cpred(cum,start)[,2]
 	   cumhazleft <- cum * RR 
 	}
@@ -295,7 +299,7 @@ if (class(margsurv)!="coxph") { ## {{{
        time.group <- as.integer(factor(qqc, labels = 1:(nrow(Biid)-1)))
        maxtimesim <- nrow(Biid); 
     } 
-    if (class(margsurv)=="cox.aalen")  { 
+    if (inherits(margsurv,"cox.aalen"))  { 
        times <- margsurv$time.sim.resolution 
        Ntimes <-length(times)
     }
@@ -356,7 +360,7 @@ if (class(margsurv)!="coxph") { ## {{{
    theta.iid  <- matrix(nparout[[43]],antsecluster,ptheta); 
    theta.iid <- theta.iid %*% SthetaI
 
-  DUbeta <- matrix(nparout[[45]],ptheta,1);  
+###  DUbeta <- matrix(nparout[[45]],pz,ptheta);  
 ###  if (is.null(call.secluster) & is.null(max.clust)) rownames(theta.iid) <- unique(cluster.call) else rownames(theta.iid) <- unique(se.clusters)
 
    ud <- list(cum = cumint, var.cum = vcum, robvar.cum = Rvcu, 
@@ -383,7 +387,7 @@ if (class(margsurv)!="coxph") { ## {{{
   attr(ud,"var.link")<-var.link
   attr(ud,"beta.fixed")<-beta.fixed
   attr(ud,"marg.model")<-class(margsurv)
-  attr(ud,"DUbeta")<-DUbeta
+###  attr(ud,"DUbeta")<-DUbeta
 
   return(ud) 
   ## }}} 
