@@ -2,6 +2,7 @@
 //#include <stdio.h>
 #include <stdarg.h>
 #include <math.h>
+#define USE_FC_LEN_T
 #include <R_ext/BLAS.h>
 #include <R_ext/Lapack.h>
 #include <R_ext/Linpack.h>
@@ -9,6 +10,12 @@
 #include <R_ext/Random.h>
 #include "matrix.h"
 
+#ifndef FCONE
+#define FCONE
+#endif
+
+
+
 void free_mat(matrix *M){
   Free(M->entries);
   Free(M);
@@ -55,43 +62,35 @@ void print_a_matrix(matrix *M){
 /* DPOTRI - compute the inverse of a real symmetric positive */
 /* definite matrix A using the Cholesky factorization A = U**T*U */
 /* or A = L*L**T computed by DPOTRF */
-extern void F77_SUB(dpotri)(const char* uplo, const int* n,
-		 double* a, const int* lda, int* info);
-
-
+//extern void F77_SUB(dpotri)(const char* uplo, const int* n, double* a, const int* lda, int* info);
+//
 /* DPOTRF - compute the Cholesky factorization of a real */
 /* symmetric positive definite matrix A */
-extern void F77_SUB(dpotrf)(const char* uplo, const int* n,
-		 double* a, const int* lda, int* info);
-
-
-extern void F77_SUB(dgemm)(const char *transa, const char *transb, const int *m,
-		const int *n, const int *k, const double *alpha,
-		const double *a, const int *lda,
-		const double *b, const int *ldb,
-		const double *beta, double *c, const int *ldc);
-
+//extern void F77_SUB(dpotrf)(const char* uplo, const int* n, double* a, const int* lda, int* info);
+//
+//extern void F77_SUB(dgemm)(const char *transa, const char *transb, const int *m,
+//		const int *n, const int *k, const double *alpha,
+//		const double *a, const int *lda,
+//		const double *b, const int *ldb,
+//		const double *beta, double *c, const int *ldc);
+//
 /* DGEMV - perform one of the matrix-vector operations */
 /* y := alpha*A*x + beta*y, or y := alpha*A'*x + beta*y,  */
-
-extern void F77_SUB(dgemv)(const char *trans, const int *m, const int *n,
-		const double *alpha, const double *a, const int *lda,
-		const double *x, const int *incx, const double *beta,
-		double *y, const int *incy);
-
-
+//
+//extern void F77_SUB(dgemv)(const char *trans, const int *m, const int *n,
+//		const double *alpha, const double *a, const int *lda,
+//		const double *x, const int *incx, const double *beta,
+//		double *y, const int *incy);
+//
+//
 /* DGETRF - compute an LU factorization of a general M-by-N */
 /* matrix A using partial pivoting with row interchanges */
-extern void
-F77_SUB(dgetrf)(const int* m, const int* n, double* a, const int* lda,
-                 int* ipiv, int* info);
-
-
+//extern void F77_SUB(dgetrf)(const int* m, const int* n, double* a, const int* lda, int* ipiv, int* info);
+//
+//
 /* DGETRI - compute the inverse of a matrix using the LU */
 /* factorization computed by DGETRF */
-extern void
-F77_SUB(dgetri)(const int* n, double* a, const int* lda,
-                 int* ipiv, double* work, const int* lwork, int* info);
+//extern void F77_SUB(dgetri)(const int* n, double* a, const int* lda, int* ipiv, double* work, const int* lwork, int* info);
 
 
 // cumsum of matrix apply(X,2,cusum)
@@ -260,16 +259,16 @@ void MtM(matrix *M, matrix *A){
   // Ensure that M and A do not occupy the same memory. 
   if(M != A){
     // the results of 1.0 * t(M) %*% M + 0.0 * c is stored in c
-    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries, &lda,
-		    M->entries, &ldb, &beta, A->entries, &ldc FCONE FCONE);
+    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries, &lda, M->entries, &ldb, &beta, A->entries, &ldc FCONE FCONE);
   } else {
     // if M and A occupy the same memory, store the results in a
     // temporary matrix. 
     matrix *temp;
     malloc_mat(nrow_matrix(A),ncol_matrix(A),temp);
 
-    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries, &lda,
-		    M->entries, &ldb, &beta, temp->entries, &ldc FCONE FCONE);
+    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries, &lda, M->entries, &ldb, &beta, temp->entries, &ldc FCONE FCONE);
+//F77_CALL(dgemm)("N", "T", &nrx, &ncy, &ncx, &one, x, &nrx, y, &nry, &zero, z, &nrx FCONE FCONE);
+
 
     // Copy these results into A, then remove the temporary matrix
     mat_copy(temp,A);
@@ -337,7 +336,7 @@ void choleskyunsafe(matrix *A, matrix *AI){ // {{{
     // First find the Cholesky factorization of A,
     // stored as an upper triangular matrix
     char uplo1 = 'U'; // lower version 
-    F77_CALL(dpotrf)(&uplo1, &n, AI->entries, &n, &info FCONE FCONE); 
+    F77_CALL(dpotrf)(&uplo1, &n, AI->entries, &n, &info FCONE); 
 
     // Lastly turn the vector a into the matrix AI
     // Take only the lower triangular portion, since this 
@@ -418,7 +417,7 @@ void invertSPDunsafe(matrix *A, matrix *AI){
 //  dqrdc(x,ldx,n,p, qraux,jpvt,work,job)
 //  F77_CALL(dqrdc)(AI->entries, &n, &n, &n, &rank, qraux, pivot, work,job);
 //  dqrdc2(x,ldx,n,p,tol,k,qraux,jpvt,work)
-  F77_CALL(dqrdc2)(AI->entries, &n, &n, &n, &tol, &rank, qraux, pivot, work FCONE FCONE);
+  F77_CALL(dqrdc2)(AI->entries, &n, &n, &n, &tol, &rank, qraux, pivot, work);
 
   for(i = 0; i < n; i++){
     for(j = 0; j < i; j++){
@@ -428,7 +427,7 @@ void invertSPDunsafe(matrix *A, matrix *AI){
 
   job = 1; // Indicates that AI is upper triangular
   rcond = 999.0;
-  F77_CALL(dtrco)(AI->entries, &n, &n, &rcond, z, &job FCONE FCONE);
+  F77_CALL(dtrco)(AI->entries, &n, &n, &rcond, z, &job);
     
   if(rcond < tol){
     Rprintf("Error in invertSPD: estimated condition number = %7.7e\n",1/rcond); 
@@ -449,7 +448,7 @@ void invertSPDunsafe(matrix *A, matrix *AI){
 
     // First find the Cholesky factorization of A,
     // stored as an upper triangular matrix
-    F77_CALL(dpotrf)(&uplo, &n, AI->entries, &lda, &info FCONE FCONE); 
+    F77_CALL(dpotrf)(&uplo, &n, AI->entries, &lda, &info FCONE); 
 
     if(info < 0){
       Rprintf("Error in invertSPD: arg %d of DPOTRF\n",-info);
@@ -458,7 +457,7 @@ void invertSPDunsafe(matrix *A, matrix *AI){
     } 
        
     // then use this factorization to compute the inverse of A
-    F77_CALL(dpotri)(&uplo, &n, AI->entries, &lda, &info FCONE FCONE);
+    F77_CALL(dpotri)(&uplo, &n, AI->entries, &lda, &info FCONE);
 
     if(info != 0){
       Rprintf("Error in invertSPD: DPOTRI returned info = %d \n",info);
@@ -498,16 +497,14 @@ void Mv(matrix *M, vector *v1, vector *v2){
   
   // Ensure that v1 and v2 do not occupy the same memory. 
   if(v1 != v2){
-    F77_CALL(dgemv)(&trans, &nrow, &ncol, &alpha, M->entries, &nrow,
-		    v1->entries, &incx, &beta, v2->entries, &incy FCONE FCONE);
+    F77_CALL(dgemv)(&trans, &nrow, &ncol, &alpha, M->entries, &nrow, v1->entries, &incx, &beta, v2->entries, &incy FCONE);
   } else {
     // if v1 and v2 occupy the same memory, store the results in a
     // temporary vector. 
     vector *temp;
     malloc_vec(length_vector(v2),temp);
 
-    F77_CALL(dgemv)(&trans, &nrow, &ncol, &alpha, M->entries, &nrow,
-		    v1->entries, &incx, &beta, temp->entries, &incy FCONE FCONE);
+    F77_CALL(dgemv)(&trans, &nrow, &ncol, &alpha, M->entries, &nrow, v1->entries, &incx, &beta, temp->entries, &incy FCONE);
     
     // Copy these results into A, then remove the temporary matrix
     vec_copy(temp,v2);    
@@ -537,16 +534,14 @@ void vM(matrix *M, vector *v1, vector *v2){
   
   // Ensure that v1 and v2 do not occupy the same memory. 
   if(v1 != v2){
-    F77_CALL(dgemv)(&trans, &nrow, &ncol, &alpha, M->entries, &nrow,
-		    v1->entries, &incx, &beta, v2->entries, &incy FCONE FCONE);
+    F77_CALL(dgemv)(&trans, &nrow, &ncol, &alpha, M->entries, &nrow, v1->entries, &incx, &beta, v2->entries, &incy FCONE );
   } else {
     // if v1 and v2 occupy the same memory, store the results in a
     // temporary vector. 
     vector *temp;
     malloc_vec(length_vector(v2),temp);
 
-    F77_CALL(dgemv)(&trans, &nrow, &ncol, &alpha, M->entries, &nrow,
-		    v1->entries, &incx, &beta, temp->entries, &incy FCONE FCONE);
+    F77_CALL(dgemv)(&trans, &nrow, &ncol, &alpha, M->entries, &nrow, v1->entries, &incx, &beta, temp->entries, &incy FCONE);
     
     // Copy these results into A, then remove the temporary matrix
     vec_copy(temp,v2);    
@@ -1041,8 +1036,7 @@ void MtA(matrix *M, matrix *A, matrix *Mout){
   // Ensure that Mout does not occupy the same memory as M or A 
   if(Mout != A && Mout != M){
     // the results of 1.0 * t(M) %*% A + 0.0 * Mout is stored in Mout
-    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries,
-		    &lda, A->entries, &ldb, &beta, Mout->entries, &ldc FCONE FCONE);
+    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries, &lda, A->entries, &ldb, &beta, Mout->entries, &ldc FCONE FCONE);
   } else {
     // if M and A occupy the same memory, store the results in a
     // temporary matrix. 
@@ -1050,8 +1044,7 @@ void MtA(matrix *M, matrix *A, matrix *Mout){
     malloc_mat(nrow_matrix(Mout),ncol_matrix(Mout),temp);
 
     // the results of 1.0 * t(M) %*% A + 0.0 * Mout is stored in temp
-    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries,
-		    &lda, A->entries, &ldb, &beta, temp->entries, &ldc FCONE FCONE);
+    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries, &lda, A->entries, &ldb, &beta, temp->entries, &ldc FCONE FCONE);
     
     // Copy these results into A, then remove the temporary matrix
     mat_copy(temp,Mout);    
@@ -1085,8 +1078,7 @@ void MAt(matrix *M, matrix *A, matrix *Mout){
   // Ensure that Mout does not occupy the same memory as M or A 
   if(Mout != A && Mout != M){
     // the results of 1.0 * t(M) %*% A + 0.0 * Mout is stored in Mout
-    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries,
-		    &lda, A->entries, &ldb, &beta, Mout->entries, &ldc FCONE FCONE);
+    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries, &lda, A->entries, &ldb, &beta, Mout->entries, &ldc FCONE FCONE);
   } else {
     // if M and A occupy the same memory, store the results in a
     // temporary matrix. 
@@ -1094,8 +1086,7 @@ void MAt(matrix *M, matrix *A, matrix *Mout){
     malloc_mat(nrow_matrix(Mout),ncol_matrix(Mout),temp);
 
     // the results of 1.0 * t(M) %*% A + 0.0 * Mout is stored in temp
-    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries,
-		    &lda, A->entries, &ldb, &beta, temp->entries, &ldc FCONE FCONE);
+    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries, &lda, A->entries, &ldb, &beta, temp->entries, &ldc FCONE FCONE);
     
     // Copy these results into Mout, then remove the temporary matrix
     mat_copy(temp,Mout);    
@@ -1185,11 +1176,11 @@ void invertUnsafe(matrix *A, matrix *Ainv){
     }
   }
 
-  anorm = F77_NAME(dlange)("O", &n, &n, Ainv->entries, &lda, dwork);
+  anorm = F77_NAME(dlange)("O", &n, &n, Ainv->entries, &lda, dwork FCONE);
 
   // First find the LU factorization of A,
   // stored as an upper triangular matrix
-  F77_CALL(dgetrf)(&n, &n, Ainv->entries, &lda, ipiv, &info FCONE FCONE);
+  F77_CALL(dgetrf)(&n, &n, Ainv->entries, &lda, ipiv, &info );
 
   if(info != 0){
     //Avoid printing this error message
@@ -1201,7 +1192,7 @@ void invertUnsafe(matrix *A, matrix *Ainv){
     for(i = 0; i < n; i++){
       iwork[i]= ipiv[i];
     }
-    F77_CALL(dgecon)("O", &n, Ainv->entries, &lda, &anorm, &rcond, dwork, iwork,  &info FCONE FCONE);
+    F77_CALL(dgecon)("O", &n, Ainv->entries, &lda, &anorm, &rcond, dwork, iwork,  &info FCONE );
     
     if(info != 0){
       //Avoid printing this error message
@@ -1217,7 +1208,7 @@ void invertUnsafe(matrix *A, matrix *Ainv){
     }
 
     // then use this factorization to compute the inverse of A
-    F77_CALL(dgetri)(&n, Ainv->entries, &lda, ipiv, work, &lwork, &info FCONE FCONE);
+    F77_CALL(dgetri)(&n, Ainv->entries, &lda, ipiv, work, &lwork, &info );
 
     if(info != 0){
       Rprintf("Error in invert: DPOTRI returned info = %d \n",info);
@@ -1265,11 +1256,11 @@ void invertUnsafeS(matrix *A, matrix *Ainv,int silent){
     }
   }
 
-  anorm = F77_NAME(dlange)("O", &n, &n, Ainv->entries, &lda, dwork);
+  anorm = F77_NAME(dlange)("O", &n, &n, Ainv->entries, &lda, dwork FCONE);
 
   // First find the LU factorization of A,
   // stored as an upper triangular matrix
-  F77_CALL(dgetrf)(&n, &n, Ainv->entries, &lda, ipiv, &info FCONE FCONE);
+  F77_CALL(dgetrf)(&n, &n, Ainv->entries, &lda, ipiv, &info );
 
   if(info != 0){
     //Avoid printing this error message
@@ -1280,7 +1271,7 @@ void invertUnsafeS(matrix *A, matrix *Ainv,int silent){
     for(i = 0; i < n; i++){
       iwork[i]= ipiv[i];
     }
-    F77_CALL(dgecon)("O", &n, Ainv->entries, &lda, &anorm, &rcond, dwork, iwork,  &info FCONE FCONE);
+    F77_CALL(dgecon)("O", &n, Ainv->entries, &lda, &anorm, &rcond, dwork, iwork,  &info FCONE );
     
     if(info != 0){
       //Avoid printing this error message
@@ -1298,7 +1289,7 @@ void invertUnsafeS(matrix *A, matrix *Ainv,int silent){
     }
 
     // then use this factorization to compute the inverse of A
-    F77_CALL(dgetri)(&n, Ainv->entries, &lda, ipiv, work, &lwork, &info FCONE FCONE);
+    F77_CALL(dgetri)(&n, Ainv->entries, &lda, ipiv, work, &lwork, &info);
 
     if(info != 0 ){
       mat_zeros(Ainv);
@@ -1340,8 +1331,7 @@ void MxA(matrix *M, matrix *A, matrix *Mout){
   if(Mout != A && Mout != M){
     // the results of 1.0 * M %*% A + 0.0 * c is stored in c
     // therfore we do not need to initialise c
-    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries, &lda,
-		    A->entries, &ldb, &beta, Mout->entries, &ldc FCONE FCONE);
+    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries, &lda, A->entries, &ldb, &beta, Mout->entries, &ldc FCONE FCONE);
   } else {
     // if M and A occupy the same memory, store the results in a
     // temporary matrix. 
@@ -1350,8 +1340,7 @@ void MxA(matrix *M, matrix *A, matrix *Mout){
 
     // the results of 1.0 * M %*% A + 0.0 * c is stored in c
     // therfore we do not need to initialise c
-    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries, &lda,
-		    A->entries, &ldb, &beta, temp->entries, &ldc FCONE FCONE);
+    F77_CALL(dgemm)(&transa, &transb, &m, &n, &k, &alpha, M->entries, &lda, A->entries, &ldb, &beta, temp->entries, &ldc FCONE FCONE);
     
     // Copy these results into Mout, then remove the temporary matrix
     mat_copy(temp,Mout);    
